FromValue

Trait FromValue 

pub trait FromValue: Sized {
    // Required method
    fn from_value(value: Value) -> Result<Self>;
}
Converts a Value read from a result row into a Rust type.

Returns an Err when the stored value cannot be coerced to the requested type (for example a NULL read into a non-optional field).

Required Methods

fn from_value(value: Value) -> Result<Self>

Attempts to read this type from a database value.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl FromValue for OffsetDateTime

Source

fn from_value(value: Value) -> Result<Self>

Source

impl FromValue for String

Source

fn from_value(value: Value) -> Result<Self>

Source

impl FromValue for Uuid

Source

fn from_value(value: Value) -> Result<Self>

Source

impl FromValue for Value

Source

fn from_value(value: Value) -> Result<Self>

Source

impl FromValue for Vec<String>

Source

fn from_value(value: Value) -> Result<Self>

Source

impl FromValue for Vec<bool>

Source

fn from_value(value: Value) -> Result<Self>

Source

impl FromValue for Vec<f64>

Source

fn from_value(value: Value) -> Result<Self>

Source

impl FromValue for Vec<i32>

Source

fn from_value(value: Value) -> Result<Self>

Source

impl FromValue for Vec<i64>

Source

fn from_value(value: Value) -> Result<Self>

Source

impl FromValue for Vec<u8>

Source

fn from_value(value: Value) -> Result<Self>

Source

impl FromValue for bool

Source

fn from_value(value: Value) -> Result<Self>

Source

impl FromValue for f32

Source

fn from_value(value: Value) -> Result<Self>

Source

impl FromValue for f64

Source

fn from_value(value: Value) -> Result<Self>

Source

impl FromValue for i8

Source

fn from_value(value: Value) -> Result<Self>

Source

impl FromValue for i16

Source

fn from_value(value: Value) -> Result<Self>

Source

impl FromValue for i32

Source

fn from_value(value: Value) -> Result<Self>

Source

impl FromValue for i64

Source

fn from_value(value: Value) -> Result<Self>

Source

impl FromValue for u8

Source

fn from_value(value: Value) -> Result<Self>

Source

impl FromValue for u16

Source

fn from_value(value: Value) -> Result<Self>

Source

impl FromValue for u32

Source

fn from_value(value: Value) -> Result<Self>

Source

impl FromValue for u64

Source

fn from_value(value: Value) -> Result<Self>

Source

impl FromValue for usize

Source

fn from_value(value: Value) -> Result<Self>

Source

impl<T: FromValue> FromValue for Option<T>

Source

fn from_value(value: Value) -> Result<Self>

Implementors

Source

impl FromValue for tork_orm_core::Value